@@ -1,7 +1,7 @@
 package Perinci::Sub::Wrapper;
 
-our $DATE = '2015-02-26'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010001;
 use strict;
@@ -261,7 +261,7 @@ sub push_lines {
         for my $l (@lines) {
             $l->[2] =
                 $self->{_cur_handler} ?
-                    "$self->{_cur_handler} p=".$self->{_cur_handler_meta}{prio}
+                    "$self->{_cur_handler} prio=".$self->{_cur_handler_meta}{prio}
                         : "";
         }
     }
@@ -288,7 +288,7 @@ sub _join_codes {
             if (defined $l->[2]) {
                 my $num_ws = 80 - length($s);
                 $num_ws = 1 if $num_ws < 1;
-                $s .= (" " x $num_ws) . "# $l->[2]";
+                $s .= (" " x $num_ws) . "## $l->[2]";
             }
             push @lines, $s;
         }
@@ -1366,7 +1366,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-This document describes version 0.75 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-26.
+This document describes version 0.76 of Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-04-25.
 
 =head1 SYNOPSIS
 
@@ -1683,7 +1683,7 @@ $Log_Perinci_Wrapper_Code is set to true, generated wrapper source code is
 logged at trace level using L<Log::Any>. It can be displayed, for example, using
 L<Log::Any::App>:
 
- % LOG_PERINCI_WRAPPER_CODE=1 TRACE=1 \
+ % LOG=1 LOG_PERINCI_WRAPPER_CODE=1 TRACE=1 \
    perl -MLog::Any::App -MPerinci::Sub::Wrapper=wrap_sub \
    -e 'wrap_sub(sub=>sub{}, meta=>{v=>1.1, args=>{a=>{schema=>"int"}}});'
 
