@@ -1,7 +1,7 @@
 package Test::Perinci::Sub::Wrapper;
 
-our $DATE = '2015-02-26'; # DATE
-our $VERSION = '0.75'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '0.76'; # VERSION
 
 use 5.010;
 use strict;
@@ -150,6 +150,12 @@ sub test_wrap {
                         or diag explain $call_res;
                 }
 
+                if (exists $test_args{call_actual_res}) {
+                    is_deeply($call_res->[2], $test_args{call_actual_res},
+                              "call actual res")
+                        or diag explain $call_res->[2];
+                }
+
                 if (exists $test_args{call_actual_res_re}) {
                     like($call_res->[2], $test_args{call_actual_res_re},
                          "call actual res");
@@ -192,7 +198,7 @@ sub test_wrap {
 
                         if (exists $call->{actual_res}) {
                             is_deeply($res->[2], $call->{actual_res}, "actual res")
-                                or diag explain $res;
+                                or diag explain $res->[2];
                         }
 
                         if (exists $call->{actual_res_re}) {
@@ -228,7 +234,7 @@ Test::Perinci::Sub::Wrapper - Provide test_wrap() to test wrapper
 
 =head1 VERSION
 
-This document describes version 0.75 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-02-26.
+This document describes version 0.76 of Test::Perinci::Sub::Wrapper (from Perl distribution Perinci-Sub-Wrapper), released on 2015-04-25.
 
 =for Pod::Coverage test_wrap
 
